@@ -5,16 +5,33 @@
 
 #include <pipewire/pipewire.h>
 
-#include "collections/string.h"
-#include "collections/list.h"
 #include "collections/hashmap.h"
+#include "collections/vec.h"
 
 struct route {
-    int32_t device, index;
-    struct string description;
+    int32_t index;
+    int32_t device;
     uint32_t direction; /* enum spa_direction */
 
-    LIST_ENTRY link;
+    VEC(int32_t) devices;
+    VEC(int32_t) profiles;
+
+    char *description;
+    char *name;
+};
+
+struct profile {
+    int32_t index;
+
+    char *description;
+    char *name;
+};
+
+enum device_modified_params {
+    ROUTE = 1 << 0,
+    ENUM_ROUTE = 1 << 1,
+    PROFILE = 1 << 2,
+    ENUM_PROFILE = 1 << 3,
 };
 
 struct device {
@@ -23,16 +40,21 @@ struct device {
 
     uint32_t id;
 
+    enum device_modified_params modified_params;
+
+    VEC(struct route) routes;
+    VEC(struct route) active_routes;
+    VEC(struct profile) profiles;
+    /* FIXME: relies on the assumption that only one profile can be active at a time. */
+    struct profile *active_profile;
+
+    /* needed to atomically update routes and profiles */
     struct {
-        LIST_HEAD all;
-        LIST_HEAD active;
-    } routes[2];
-    struct {
-        LIST_HEAD all;
-        LIST_HEAD active;
-    } new_routes[2]; /* needed to atomically update routes. TODO: better way to do it? */
-    static_assert(SPA_DIRECTION_INPUT == 0 && SPA_DIRECTION_OUTPUT == 1,
-                  "Unexpected values of spa_direction enums");
+        VEC(struct route) routes;
+        VEC(struct route) active_routes;
+        VEC(struct profile) profiles;
+        struct profile *active_profile;
+    } staging;
 
     HASHMAP_ENTRY hash;
 };
