@@ -18,7 +18,6 @@ enum color_pair {
     GREEN = 1,
     YELLOW = 2,
     RED = 3,
-    GRAY = 4,
 };
 
 struct tui tui = {0};
@@ -217,7 +216,7 @@ static void tui_draw_node(const struct tui_tab_item *item, bool draw_uncondition
     DRAW_IF(focus_changed || volume_changed || mute_changed) {
         /* draw info about each channel */
         if (muted) {
-            wattron(win, COLOR_PAIR(GRAY));
+            wattron(win, A_DIM);
         }
 
         for (uint32_t i = 0; i < node->props.channel_count; i++) {
@@ -243,14 +242,14 @@ static void tui_draw_node(const struct tui_tab_item *item, bool draw_uncondition
             }
         }
 
-        wattroff(win, COLOR_PAIR(GRAY));
+        wattroff(win, A_DIM);
     }
 
     /* draw decorations (also focused markers) */
     DRAW_IF(focus_changed || unlocked_channels_changed || mute_changed) {
         /* draw info about each channel */
         if (muted) {
-            wattron(win, COLOR_PAIR(GRAY));
+            wattron(win, A_DIM);
         }
 
         for (uint32_t i = 0; i < node->props.channel_count; i++) {
@@ -289,7 +288,7 @@ static void tui_draw_node(const struct tui_tab_item *item, bool draw_uncondition
             mvwadd_wch(win, pos, volume_bar_start + volume_bar_width + 1, &cchar_focus);
         }
 
-        wattroff(win, COLOR_PAIR(GRAY));
+        wattroff(win, A_DIM);
     }
 
     DRAW_IF(focus_changed || port_changed) {
@@ -298,45 +297,52 @@ static void tui_draw_node(const struct tui_tab_item *item, bool draw_uncondition
 
         if (node->device != NULL) {
             int written = 0, chars;
-            chars = snprintf(buf, usable_width - written, "Ports: ");
+            chars = snprintf(buf, usable_width - written, "Routes: ");
             mvwaddnstr(win, ports_line_pos, 1 + written, buf, usable_width - written);
             written = (written + chars > usable_width) ? usable_width : (written + chars);
 
             const struct route *active_route = node_get_active_route(node);
-            const LIST_HEAD *routes = node_get_routes(node);
-            const struct route *route;
+            const struct route *const *routes;
+            const size_t nroutes = node_get_available_routes(node, &routes);
 
             if (active_route != NULL) {
                 /* draw active route first */
                 chars = snprintf(buf, usable_width - written, "%s",
-                                 active_route->description.data);
+                                 active_route->description);
                 mvwaddnstr(win, ports_line_pos, 1 + written, buf, usable_width - written);
                 written = (written + chars > usable_width) ? usable_width : (written + chars);
 
-                wattron(win, COLOR_PAIR(GRAY));
-                LIST_FOR_EACH(route, routes, link) {
+                wattron(win, A_DIM);
+                for (size_t i = 0; i < nroutes; i++) {
+                    const struct route *route = routes[i];
                     if (active_route != NULL && route->index == active_route->index) {
                         continue;
                     }
 
                     chars = snprintf(buf, usable_width - written, "%s%s",
-                                     config.ports_separator, route->description.data);
+                                     config.routes_separator, route->description);
                     mvwaddnstr(win, ports_line_pos, 1 + written, buf, usable_width - written);
                     written = (written + chars > usable_width) ? usable_width : (written + chars);
                 }
-            } else {
-                wattron(win, COLOR_PAIR(GRAY));
-                LIST_FOR_EACH(route, routes, link) {
-                    if (LIST_IS_FIRST(routes, &route->link)) {
+            } else if (nroutes > 0) {
+                wattron(win, A_DIM);
+                for (size_t i = 0; i < nroutes; i++) {
+                    const struct route *route = routes[i];
+                    if (i == 0) {
                         chars = snprintf(buf, usable_width - written, "%s",
-                                         route->description.data);
+                                         route->description);
                     } else {
                         chars = snprintf(buf, usable_width - written, "%s%s",
-                                         config.ports_separator, route->description.data);
+                                         config.routes_separator, route->description);
                     }
                     mvwaddnstr(win, ports_line_pos, 1 + written, buf, usable_width - written);
                     written = (written + chars > usable_width) ? usable_width : (written + chars);
                 }
+            } else {
+                wattron(win, A_DIM);
+                chars = snprintf(buf, usable_width - written, "(none)");
+                mvwaddnstr(win, ports_line_pos, 1 + written, buf, usable_width - written);
+                written = (written + chars > usable_width) ? usable_width : (written + chars);
             }
 
             if (written >= usable_width) {
@@ -347,7 +353,7 @@ static void tui_draw_node(const struct tui_tab_item *item, bool draw_uncondition
                 mvwhline(win, ports_line_pos, written + 1, ' ', usable_width - written);
             }
 
-            wattroff(win, COLOR_PAIR(GRAY));
+            wattroff(win, A_DIM);
         }
     }
 
@@ -388,11 +394,17 @@ static void tui_draw_status_bar(void) {
     wmove(tui.bar_win, 0, 0);
 
     FOR_EACH_TAB(tab) {
-        wattron(tui.bar_win, (tab == tui.tab) ? COLOR_PAIR(DEFAULT) : COLOR_PAIR(GRAY));
-        wattron(tui.bar_win, (tab == tui.tab) ? A_BOLD : 0);
+        if (tab != tui.tab) {
+            wattron(tui.bar_win, A_DIM);
+        } else {
+            wattron(tui.bar_win, A_BOLD);
+        }
         waddstr(tui.bar_win, tui_tab_name(tab));
-        wattroff(tui.bar_win, (tab == tui.tab) ? A_BOLD : 0);
-        wattroff(tui.bar_win, (tab == tui.tab) ? COLOR_PAIR(DEFAULT) : COLOR_PAIR(GRAY));
+        if (tab != tui.tab) {
+            wattroff(tui.bar_win, A_DIM);
+        } else {
+            wattroff(tui.bar_win, A_BOLD);
+        }
         waddstr(tui.bar_win, "   ");
     }
 
@@ -425,11 +437,11 @@ static void tui_repaint(bool draw_unconditionally) {
     if (bottom == 0) {
         /* empty tab */
         const char *empty = "Empty";
-        wattron(tui.pad_win, COLOR_PAIR(GRAY));
+        wattron(tui.pad_win, A_DIM);
         mvwaddstr(tui.pad_win,
                   (tui.term_height - 1) / 2, (tui.term_width / 2) - (strlen(empty) / 2),
                   empty);
-        wattroff(tui.pad_win, COLOR_PAIR(GRAY));
+        wattroff(tui.pad_win, A_DIM);
     }
 
     pnoutrefresh(tui.pad_win,
@@ -746,7 +758,7 @@ static void on_port_selection_done(struct tui_menu *menu, struct tui_menu_item *
     tui_repaint(true);
 }
 
-void tui_bind_select_port(union tui_bind_data data) {
+void tui_bind_select_route(union tui_bind_data data) {
     if (TUI_ACTIVE_TAB.focused == NULL \
         || !TUI_ACTIVE_TAB.focused->node->has_device \
         || tui.menu_active) {
@@ -754,34 +766,32 @@ void tui_bind_select_port(union tui_bind_data data) {
     }
 
     const struct route *active_route = node_get_active_route(TUI_ACTIVE_TAB.focused->node);
-    const LIST_HEAD *routes = node_get_routes(TUI_ACTIVE_TAB.focused->node);
-    const struct route *route;
+    const struct route *const *routes;
+    const size_t nroutes = node_get_available_routes(TUI_ACTIVE_TAB.focused->node, &routes);
 
-    unsigned int n_items = 0;
-    LIST_FOR_EACH(route, routes, link) {
-        n_items += 1;
+    if (nroutes < 2) {
+        return;
     }
 
-    tui.menu = tui_menu_create(n_items);
+    tui.menu = tui_menu_create(nroutes);
     tui.menu->callback = on_port_selection_done;
     tui.menu->data.uint = TUI_ACTIVE_TAB.focused->node->id;
 
     tui_menu_resize(tui.menu, tui.term_width, tui.term_height);
 
-    string_printf(&tui.menu->header, "Select port for %ls",
+    string_printf(&tui.menu->header, "Select route for %ls",
                   TUI_ACTIVE_TAB.focused->node->node_name.data);
 
-    int i = 0;
-    LIST_FOR_EACH_REVERSE(route, routes, link) {
+    for (size_t i = 0; i < nroutes; i++) {
+        const struct route *route = routes[i];
         struct tui_menu_item *item = &tui.menu->items[i];
-        string_printf(&item->str, "%d. %s", route->index, route->description.data);
+        string_printf(&item->str, "%d. %s (%s)",
+                      route->index, route->description, route->name);
         item->data.uint = route->index;
 
         if (active_route != NULL && route->index == active_route->index) {
             tui.menu->selected = i;
         }
-
-        i += 1;
     }
 
     tui.menu_active = true;
@@ -1076,7 +1086,6 @@ int tui_init(void) {
     init_pair(GREEN, COLOR_GREEN, -1);
     init_pair(YELLOW, COLOR_YELLOW, -1);
     init_pair(RED, COLOR_RED, -1);
-    init_pair(GRAY, 8, -1);
 
     FOR_EACH_TAB(tab) {
         LIST_INIT(&tui.tabs[tab].items);
