@@ -4,6 +4,7 @@
 #include <ncurses.h>
 
 #include "pw/node.h"
+#include "collections/list.h"
 #include "lib/pollen/pollen.h"
 
 enum tui_tab {
@@ -125,7 +126,7 @@ enum tui_nothing { NOTHING };
 void tui_bind_focus_first(union tui_bind_data data);
 void tui_bind_focus_last(union tui_bind_data data);
 
-void tui_bind_select_port(union tui_bind_data data);
+void tui_bind_select_route(union tui_bind_data data);
 void tui_bind_confirm_selection(union tui_bind_data data);
 void tui_bind_cancel_selection(union tui_bind_data data);
 
